==> openjdk-19_19~23ea.orig.tar.xz: openjdk-19-19~23ea/test/jdk/java/beans/XMLDecoder/spec/TestVar.java <==
/*
 * Copyright (c) 2008, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @summary Tests <var> element
 * @run main/othervm -Djava.security.manager=allow TestVar
 * @author Sergey Malenkov
 */

import java.beans.XMLDecoder;

public final class TestVar extends AbstractTest {
    public static final String XML
            = "<java id=\"decoder\">\n"
            + " <var idref=\"decoder\"/>\n"
            + " <var id=\"another\" idref=\"decoder\"/>\n"
            + " <var idref=\"another\"/>\n"
            + " <var id=\"decoder\" idref=\"another\"/>\n"
            + " <var idref=\"decoder\"/>\n"
            + "</java>";

    public static void main(String[] args) {
        new TestVar().test(true);
    }

    @Override
    protected void validate(XMLDecoder decoder) {
        for (int i = 0; i < 3; i++) {
            if (decoder != decoder.readObject()) {
                throw new Error("decoder instance expected");
            }
        }
    }
}

==> openjdk-25_25~16ea.orig.tar.xz: openjdk-25-25~16ea/test/jdk/java/beans/XMLDecoder/spec/TestVar.java <==
/*
 * Copyright (c) 2008, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @summary Tests <var> element
 * @run main/othervm TestVar
 * @author Sergey Malenkov
 */

import java.beans.XMLDecoder;

public final class TestVar extends AbstractTest {
    public static final String XML
            = "<java id=\"decoder\">\n"
            + " <var idref=\"decoder\"/>\n"
            + " <var id=\"another\" idref=\"decoder\"/>\n"
            + " <var idref=\"another\"/>\n"
            + " <var id=\"decoder\" idref=\"another\"/>\n"
            + " <var idref=\"decoder\"/>\n"
            + "</java>";

    public static void main(String[] args) {
        new TestVar().test();
    }

    @Override
    protected void validate(XMLDecoder decoder) {
        for (int i = 0; i < 3; i++) {
            if (decoder != decoder.readObject()) {
                throw new Error("decoder instance expected");
            }
        }
    }
}
